==> haskell-refinery-0.4.0.0-169-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-refinery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 refinery
version:              0.4.0.0
visibility:           public
id:                   refinery-0.4.0.0-3WmWWaSFg4265rhpzB5HGN
key:                  refinery-0.4.0.0-3WmWWaSFg4265rhpzB5HGN
license:              BSD-3-Clause
copyright:            2019 Reed Mullanix
maintainer:           reedmullanix@gmail.com
author:               Reed Mullanix
homepage:             https://github.com/totbwf/refinery#readme
synopsis:             Toolkit for building proof automation systems
description:
    Please see the README on GitHub at <https://github.com/githubuser/refinery#readme>

category:             Language
abi:                  8c5d58c416da30f22e2450df9df1f113
exposed:              True
exposed-modules:
    Refinery.ProofState Refinery.Tactic Refinery.Tactic.Internal

hidden-modules:       Paths_refinery
import-dirs:          /usr/lib/ghc-9.0.2/site-local/refinery-0.4.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/refinery-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-refinery
hs-libraries:         HSrefinery-0.4.0.0-3WmWWaSFg4265rhpzB5HGN
depends:
    base-4.15.1.0 exceptions-0.10.4 mmorph-1.2.0-2iQgHTViuScASaZTADZaI1
    mtl-2.2.2

haddock-interfaces:   /usr/share/doc/haskell-refinery/html/refinery.haddock
haddock-html:         /usr/share/doc/haskell-refinery/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-refinery-0.4.0.0-173-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-refinery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 refinery
version:              0.4.0.0
visibility:           public
id:                   refinery-0.4.0.0-EZcvKGqiRI68IsQZocFBdi
key:                  refinery-0.4.0.0-EZcvKGqiRI68IsQZocFBdi
license:              BSD-3-Clause
copyright:            2019 Reed Mullanix
maintainer:           reedmullanix@gmail.com
author:               Reed Mullanix
homepage:             https://github.com/totbwf/refinery#readme
synopsis:             Toolkit for building proof automation systems
description:
    Please see the README on GitHub at <https://github.com/githubuser/refinery#readme>

category:             Language
abi:                  af61a3be7332f30a4ed11361e26558a5
exposed:              True
exposed-modules:
    Refinery.ProofState Refinery.Tactic Refinery.Tactic.Internal

hidden-modules:       Paths_refinery
import-dirs:          /usr/lib/ghc-9.2.8/site-local/refinery-0.4.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/refinery-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-refinery
hs-libraries:         HSrefinery-0.4.0.0-EZcvKGqiRI68IsQZocFBdi
depends:
    base-4.16.4.0 exceptions-0.10.4 mmorph-1.2.0-86rQZSuTSAZIoeBosVXsFi
    mtl-2.2.2

haddock-interfaces:   /usr/share/doc/haskell-refinery/html/refinery.haddock
haddock-html:         /usr/share/doc/haskell-refinery/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
